Author: jimtabor
Date: Sun Jun 1 12:47:46 2008
New Revision: 33817
URL: http://svn.reactos.org/svn/reactos?rev=33817&view=rev
Log:
Stefan Ginsberg <stefan__100__ at hotmail.com> - Move MetaFile stubs into Metafile.c.
Modified:
trunk/reactos/subsystems/win32/win32k/objects/metafile.c
trunk/reactos/subsystems/win32/win32k/stubs/stubs.c
Modified: trunk/reactos/subsystems/win32/win32k/objects/metafile.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/subsystems/win32/win32k/ob…
==============================================================================
--- trunk/reactos/subsystems/win32/win32k/objects/metafile.c [iso-8859-1] (original)
+++ trunk/reactos/subsystems/win32/win32k/objects/metafile.c [iso-8859-1] Sun Jun 1 12:47:46 2008
@@ -1,34 +1,35 @@
/*
- * ReactOS W32 Subsystem
- * Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003 ReactOS Team
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */
-/* $Id$ */
+ * PROJECT: ReactOS Win32k Subsystem
+ * LICENSE: GPL - See COPYING in the top level directory
+ * FILE: win32k/objects/metafile.c
+ * PURPOSE: Metafile Implementation
+ * PROGRAMMERS: ...
+ */
+
+/* INCLUDES ******************************************************************/
#include <w32k.h>
#define NDEBUG
#include <debug.h>
-
-//
-//
-// Rewrite is in progress, this function is subject to change at any time.
-// 04/30/2007
-//
+/* System Service Calls ******************************************************/
+
+/*
+ * @unimplemented
+ */
+LONG
+APIENTRY
+NtGdiConvertMetafileRect(IN HDC hDC,
+ IN OUT PRECTL pRect)
+{
+ UNIMPLEMENTED;
+ return 0;
+}
+
+/*
+ * @unimplemented
+ */
HDC
STDCALL
NtGdiCreateMetafileDC(IN HDC hdc)
@@ -236,5 +237,37 @@
#endif
}
+/*
+ * @unimplemented
+ */
+HANDLE
+APIENTRY
+NtGdiCreateServerMetaFile(IN DWORD iType,
+ IN ULONG cjData,
+ IN PBYTE pjData,
+ IN DWORD mm,
+ IN DWORD xExt,
+ IN DWORD yExt)
+{
+ UNIMPLEMENTED;
+ return NULL;
+}
+
+/*
+ * @unimplemented
+ */
+ULONG
+APIENTRY
+NtGdiGetServerMetaFileBits(IN HANDLE hmo,
+ IN ULONG cjData,
+ OUT OPTIONAL PBYTE pjData,
+ OUT PDWORD piType,
+ OUT PDWORD pmm,
+ OUT PDWORD pxExt,
+ OUT PDWORD pyExt)
+{
+ UNIMPLEMENTED;
+ return 0;
+}
/* EOF */
Modified: trunk/reactos/subsystems/win32/win32k/stubs/stubs.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/subsystems/win32/win32k/st…
==============================================================================
--- trunk/reactos/subsystems/win32/win32k/stubs/stubs.c [iso-8859-1] (original)
+++ trunk/reactos/subsystems/win32/win32k/stubs/stubs.c [iso-8859-1] Sun Jun 1 12:47:46 2008
@@ -1650,24 +1650,6 @@
/*
* @unimplemented
*/
-HANDLE
-APIENTRY
-NtGdiCreateServerMetaFile(
- IN DWORD iType,
- IN ULONG cjData,
- IN LPBYTE pjData,
- IN DWORD mm,
- IN DWORD xExt,
- IN DWORD yExt)
-{
- UNIMPLEMENTED;
- return NULL;
-}
-
-
- /*
- * @unimplemented
- */
HBITMAP
APIENTRY
NtGdiClearBitmapAttributes(
@@ -1844,19 +1826,6 @@
{
UNIMPLEMENTED;
return FALSE;
-}
-
- /*
- * @unimplemented
- */
-LONG
-APIENTRY
-NtGdiConvertMetafileRect(
- IN HDC hdc,
- IN OUT PRECTL prect)
-{
- UNIMPLEMENTED;
- return 0;
}
/*
@@ -2433,24 +2402,6 @@
{
UNIMPLEMENTED;
return FALSE;
-}
-
- /*
- * @unimplemented
- */
-ULONG
-APIENTRY
-NtGdiGetServerMetaFileBits(
- IN HANDLE hmo,
- IN ULONG cjData,
- OUT OPTIONAL LPBYTE pjData,
- OUT PDWORD piType,
- OUT PDWORD pmm,
- OUT PDWORD pxExt,
- OUT PDWORD pyExt)
-{
- UNIMPLEMENTED;
- return 0;
}
/*
Author: cfinck
Date: Sun Jun 1 12:08:49 2008
New Revision: 33813
URL: http://svn.reactos.org/svn/reactos?rev=33813&view=rev
Log:
Don't create a new phpBB group for every user, put the user in the REGISTERED group instead
Modified:
trunk/web/reactos.org/htdocs/roscms/inc/subsys_phpbb.php
Modified: trunk/web/reactos.org/htdocs/roscms/inc/subsys_phpbb.php
URL: http://svn.reactos.org/svn/reactos/trunk/web/reactos.org/htdocs/roscms/inc/…
==============================================================================
--- trunk/web/reactos.org/htdocs/roscms/inc/subsys_phpbb.php [iso-8859-1] (original)
+++ trunk/web/reactos.org/htdocs/roscms/inc/subsys_phpbb.php [iso-8859-1] Sun Jun 1 12:08:49 2008
@@ -191,16 +191,17 @@
" $roscms_user_register)";
mysql_query($query) or die("DB error (subsys_phpbb #10)");
- /* Create a group for the user */
- $query = "INSERT INTO " . SUBSYS_PHPBB_DBNAME . ".phpbb_groups " .
- " (group_type, group_name, group_description) " .
- "VALUES (1, '', 'Personal User')";
- mysql_query($query) or die("DB error (subsys_phpbb #18)");
-
- /* Put the user in her own group */
+ /* Put the user in the REGISTERED group */
+ $query = "SELECT group_id FROM " . SUBSYS_PHPBB_DBNAME . ".phpbb_groups WHERE group_name = 'REGISTERED'";
+ $result = mysql_query($query) or die("DB error (subsys_phpbb #18)");
+ $group_id = (int)mysql_result($result, 0);
+
+ if(!$group_id)
+ die("DB error (subsys_phpbb #20)");
+
$query = "INSERT INTO " . SUBSYS_PHPBB_DBNAME . ".phpbb_user_group " .
" (group_id, user_id, user_pending) " .
- "VALUES (LAST_INSERT_ID(), $phpbb_user_id, 0)";
+ "VALUES ($group_id, $phpbb_user_id, 0)";
mysql_query($query) or die("DB error (subsys_phpbb #19)");
/* Finally, insert a row in the mapping table */